"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ava_1 = require("ava");
var graphql_1 = require("graphql");
var info_1 = require("./info");
ava_1.test('buildInfoForAllScalars: 1 field', function (t) {
    var schema = graphql_1.buildSchema("\n  type Query {\n    book: Book\n  }\n\n  type Book {\n    title: String\n  }\n  ");
    var info = info_1.buildInfoForAllScalars('book', schema, 'query');
    var selections = info.fieldNodes[0].selectionSet.selections;
    assertFields(t, selections, ['title']);
});
ava_1.test('buildInfoForAllScalars: 2 fields', function (t) {
    var schema = graphql_1.buildSchema("\n  type Query {\n    book: Book\n  }\n\n  type Book {\n    title: String\n    number: Float\n  }\n  ");
    var info = info_1.buildInfoForAllScalars('book', schema, 'query');
    var selections = info.fieldNodes[0].selectionSet.selections;
    assertFields(t, selections, ['title', 'number']);
    t.is(info.fieldName, 'book');
});
ava_1.test('buildInfoForAllScalars: excludes object type fields', function (t) {
    var schema = graphql_1.buildSchema("\n  type Query {\n    book: Book\n  }\n\n  type Book {\n    title: String\n    number: Float\n    otherBook: Book\n  }\n  ");
    var info = info_1.buildInfoForAllScalars('book', schema, 'query');
    var selections = info.fieldNodes[0].selectionSet.selections;
    assertFields(t, selections, ['title', 'number']);
    t.is(info.fieldName, 'book');
});
ava_1.test('buildInfoForAllScalars: enums', function (t) {
    var schema = graphql_1.buildSchema("\n  type Query {\n    book: Book\n  }\n\n  type Book {\n    color: Color\n  }\n\n  enum Color { Red, Blue }\n  ");
    var info = info_1.buildInfoForAllScalars('book', schema, 'query');
    var selections = info.fieldNodes[0].selectionSet.selections;
    assertFields(t, selections, ['color']);
});
ava_1.test('buildInfoForAllScalars: minimal static root field', function (t) {
    var schema = graphql_1.buildSchema("\n  type Query {\n    count: Int\n  }\n  ");
    var info = info_1.buildInfoForAllScalars('count', schema, 'query');
    t.is(info.fieldNodes.length, 0);
});
ava_1.test('buildInfoForAllScalars: mutation', function (t) {
    var schema = graphql_1.buildSchema("\n  type Query {\n    book: Int # use name root field name but different type\n  }\n\n  type Mutation {\n    book: Book\n  }\n\n  type Book {\n    title: String\n  }\n  ");
    var info = info_1.buildInfoForAllScalars('book', schema, 'mutation');
    var selections = info.fieldNodes[0].selectionSet.selections;
    assertFields(t, selections, ['title']);
});
ava_1.test('buildInfoForAllScalars: throws error when field not found', function (t) {
    var schema = graphql_1.buildSchema("\n  type Query {\n    count: Int\n  }\n  ");
    t.throws(function () { return info_1.buildInfoForAllScalars('other', schema, 'query'); });
});
ava_1.test('buildInfoFromFragment: 1 field', function (t) {
    var schema = graphql_1.buildSchema("\n  type Query {\n    book: Book\n  }\n\n  type Book {\n    title: String\n  }\n  ");
    var info = info_1.buildInfoFromFragment('book', schema, 'query', "{ title }");
    var selections = info.fieldNodes[0].selectionSet.selections;
    assertFields(t, selections, ['title']);
});
ava_1.test('buildInfoFromFragment: nested', function (t) {
    var schema = graphql_1.buildSchema("\n  type Query {\n    book: Book\n  }\n\n  type Book {\n    title: String\n    otherBook: Book\n  }\n  ");
    var fragment = "{ title otherBook { otherBook { title } } }";
    var info = info_1.buildInfoFromFragment('book', schema, 'query', fragment);
    var selections = info.fieldNodes[0].selectionSet.selections;
    t.is(selections[0].name.value, 'title');
    t.is(selections[1].name.value, 'otherBook');
    t.is(selections[1].selectionSet.selections[0].name.value, 'otherBook');
    t.is(selections[1].selectionSet.selections[0].selectionSet.selections[0].name
        .value, 'title');
});
function assertFields(t, selections, names) {
    var fields = names.map(function (value) { return ({
        kind: 'Field',
        name: { kind: 'Name', value: value },
    }); });
    var _loop_1 = function (field) {
        t.true(selections.some(function (s) { return s.kind === 'Field' && s.name.value === field.name.value; }));
    };
    for (var _i = 0, fields_1 = fields; _i < fields_1.length; _i++) {
        var field = fields_1[_i];
        _loop_1(field);
    }
    t.is(selections.length, names.length);
}
//# sourceMappingURL=info.test.js.map